cli

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2026 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Version   = "0.1.0"
	GitCommit = "dev"
	BuildDate = "unknown"
)

Functions

func Execute

func Execute() error

Types

This section is empty.

Directories

Path Synopsis
Package unit reproduces the behaviour of the legacy "go-tool u" command: it generates mocks declared in build-config.yml and runs the unit-test suite with Ginkgo, producing a coverage profile and a JUnit report.
Package unit reproduces the behaviour of the legacy "go-tool u" command: it generates mocks declared in build-config.yml and runs the unit-test suite with Ginkgo, producing a coverage profile and a JUnit report.

Jump to